#' Length of Left Middle Finger and Height for 3000 Criminals 
#' 
#' Length of left middle finger and height for 3000 criminals
#' @name anthrop
#' @docType data
#' @format Data frame with the following 2 variables: 
#' \describe{
#'   \item{finger}{length of left middle finger (cm)}
#'   \item{height}{height (inches)}
#' }
#' @source Macdonell, W. R. (1901). On criminal anthropometry and the
#' identification of criminals, \emph{Biometrika}, 1: 177--227.
#' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
#'   438.
#' @export
NULL

